# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Initial release of PlimAI package
- Basic example module with hello function
- GitHub Actions workflow for automatic publishing
- Semantic versioning support
- New get_version() function to retrieve package version

## [0.1.0] - 2024-03-09

### Added
- Initial release of PlimAI package
- Basic example module with hello function
- GitHub Actions workflow for automatic publishing
- Semantic versioning support
